<?php
/**
 * Customizer sanitize callback functions.
 *
 * @package WEN_Associate
 */

if ( ! function_exists( 'wen_associate_sanitize_select' ) ) :

	/**
	 * Sanitize select.
	 *
	 * @since 1.0.0
	 *
	 * @param mixed                $input The value to sanitize.
	 * @param WP_Customize_Setting $setting WP_Customize_Setting instance.
	 * @return mixed Sanitized value.
	 */
	function wen_associate_sanitize_select( $input, $setting ) {

		// Ensure input is a slug.
		$input = sanitize_key( $input );

		// Get list of choices from the control associated with the setting.
		$choices = $setting->manager->get_control( $setting->id )->choices;

		// If the input is a valid key, return it; otherwise, return the default.
		return ( array_key_exists( $input, $choices ) ? $input : $setting->default );

	}

endif;

if ( ! function_exists( 'wen_associate_sanitize_select_liberal' ) ) :

	/**
	 * Sanitize select, quite liberal than other select sanitization.
	 *
	 * @since 1.0.0
	 *
	 * @param mixed                $input The value to sanitize.
	 * @param WP_Customize_Setting $setting WP_Customize_Setting instance.
	 * @return mixed Sanitized value.
	 */
	function wen_associate_sanitize_select_liberal( $input, $setting ) {

		// Escape value.
		$input = esc_attr( $input );

		// Get list of choices from the control associated with the setting.
		$choices = $setting->manager->get_control( $setting->id )->choices;

		// If the input is a valid key, return it; otherwise, return the default.
		return ( array_key_exists( $input, $choices ) ? $input : $setting->default );

	}

endif;


if ( ! function_exists( 'wen_associate_sanitize_checkbox' ) ) :

	/**
	 * Sanitize checkbox.
	 *
	 * @since 1.0.0
	 *
	 * @param bool $checked Whether the checkbox is checked.
	 * @return bool Whether the checkbox is checked.
	 */
	function wen_associate_sanitize_checkbox( $checked ) {

		return ( ( isset( $checked ) && true === $checked ) ? true : false );

	}

endif;

if ( ! function_exists( 'wen_associate_sanitize_positive_integer' ) ) :

	/**
	 * Sanitize positive integer.
	 *
	 * @since 1.0.0
	 *
	 * @param int                  $input Number to sanitize.
	 * @param WP_Customize_Setting $setting WP_Customize_Setting instance.
	 * @return int Sanitized number; otherwise, the setting default.
	 */
	function wen_associate_sanitize_positive_integer( $input, $setting ) {

		$input = absint( $input );

		return ( $input ? $input : $setting->default );

	}

endif;

if ( ! function_exists( 'wen_associate_sanitize_number_range' ) ) :

	/**
	 * Sanitize number range.
	 *
	 * @since 1.0.0
	 *
	 * @see absint() https://developer.wordpress.org/reference/functions/absint/
	 *
	 * @param int                  $input Number to check within the numeric range defined by the setting.
	 * @param WP_Customize_Setting $setting WP_Customize_Setting instance.
	 * @return int|string The number, if it is zero or greater and falls within the defined range; otherwise, the setting default.
	 */
	function wen_associate_sanitize_number_range( $input, $setting ) {

		// Ensure input is an absolute integer.
		$input = absint( $input );

		// Get the input attributes associated with the setting.
		$atts = $setting->manager->get_control( $setting->id )->input_attrs;

		// Get min.
		$min = ( isset( $atts['min'] ) ? $atts['min'] : $input );

		// Get max.
		$max = ( isset( $atts['max'] ) ? $atts['max'] : $input );

		// Get Step.
		$step = ( isset( $atts['step'] ) ? $atts['step'] : 1 );

		return ( $min <= $input && $input <= $max && is_int( $input / $step ) ? $input : $setting->default );

	}

endif;

if ( ! function_exists( 'wen_associate_sanitize_footer_content' ) ) :

	/**
	 * Sanitize footer content.
	 *
	 * @since 1.0.0
	 *
	 * @param string               $input Content to be sanitized.
	 * @param WP_Customize_Setting $setting WP_Customize_Setting instance.
	 * @return string Sanitized content.
	 */
	function wen_associate_sanitize_footer_content( $input, $setting ) {

		return ( stripslashes( wp_filter_post_kses( addslashes( $input ) ) ) );

	}

endif;

if ( ! function_exists( 'wen_associate_sanitize_page_id' ) ) :

	/**
	 * Sanitize page ID.
	 *
	 * @since 1.0.0
	 *
	 * @param mixed                $input Content to be sanitized.
	 * @param WP_Customize_Setting $setting WP_Customize_Setting instance.
	 * @return mixed Sanitized value.
	 */
	function wen_associate_sanitize_page_id( $input, $setting ) {

		$input = absint( $input );

		return ( 'page' === get_post_type( $input ) ? $input : $setting->default );

	}

endif;

if ( ! function_exists( 'wen_associate_sanitize_post_id' ) ) :

	/**
	 * Sanitize post ID.
	 *
	 * @since 1.0.0
	 *
	 * @param int                  $input Post ID.
	 * @param WP_Customize_Setting $setting WP_Customize_Setting instance.
	 * @return int|string Post ID if the post is published; otherwise, the setting default.
	 */
	function wen_associate_sanitize_post_id( $input, $setting ) {

		// Ensure $input is an absolute integer.
		$input = absint( $input );

		// If $input is an ID of a published post, return it; otherwise, return the default.
		return ( ( 'publish' === get_post_status( $input ) && 'post' === get_post_type( $input ) ) ? $input : $setting->default );

	}

endif;
